EVCAuxiliary
============

.. toctree::
   :maxdepth: 1

.. automodule:: psyneulink.library.components.mechanisms.modulatory.control.evc.evcauxiliary
   :members:
   :private-members:
   :exclude-members: random, LinearCombination, EVCAuxiliaryFunction, Parameters
